Documentation — Django Grappelli 2.7.2 documentation

# Documentation

A jazzy skin for the Django admin interface.

This documentation covers version 2.7.2 of Grappelli. Grappelli is a grid-based alternative/extension to the Django administration interface.

Note

Grappelli 2.7.2 requires Django 1.8. More on Versions and Compatibility.

## Installation & Setup

- Quick start guide
  - Installation
  - Setup
  - Testing
- Customization
  - Available Settings
  - Collapsibles
  - Inline Sortables
  - Rearrange Inlines
  - Related Lookups
  - Autocomplete Lookups
  - Using TinyMCE
  - Changelist Templates
  - Changelist Filters
  - Switch User
  - Clean input types

## Dashboard

- Dashboard Setup
  - Custom dashboard
  - Custom dashboards for multiple sites
- Dashboard API
  - The Dashboard class
  - The DashboardModule class
  - The Group class
  - The LinkList class
  - The AppList class
  - The ModelList class
  - The RecentActions class
  - The Feed class

## Internals

- Internals
  - Templates
  - Javascripts

## Help

- Help
  - FAQ
  - Best Practice
  - Third Party Applications
  - Troubleshooting
  - Django Issues
  - Grappelli 2.7.x Release Notes
- Contributing
- Changelog

## Code

https://github.com/sehmaschine/django-grappelli

## Website

http://www.grappelliproject.com

## Discussion

Use the Grappelli Google Group to ask questions or discuss features.

## Versions and Compatibility

Grappelli is always developed against the latest stable Django release and is NOT tested with Djangos trunk.

- Grappelli 2.7.1 (July 22nd, 2015): Compatible with Django 1.8
- Grappelli 2.6.5 (May 28th, 2015): Compatible with Django 1.7
- Grappelli 2.5.7 (March 27th, 2015): Compatible with Django 1.6

Current development branches:

- Grappelli 2.7.2 (Development version for Django 1.8, see branch Stable/2.7.x)
- Grappelli 2.6.6 (Development version for Django 1.7, see branch Stable/2.6.x)
- Grappelli 2.5.8 (Development version for Django 1.6, see branch Stable/2.5.x)

Older versions are available at GitHub, but are not supported anymore. Support for 2.5.x and 2.6.x is limited to security issues and very important bugfixes.